﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.IO;

namespace Project_VolgaIT
{
    public partial class EditorMap : Form
    {
        int GlobalWidth;
        int GlobalHeight;
        int?[,] Opponents;
        Player igrok;


        public EditorMap(int?[,] inputOpponents, Player inputPlayer)
        {
            InitializeComponent();
            GlobalWidth = inputOpponents.GetLength(0);
            GlobalHeight = inputOpponents.GetLength(1);
            numericUpDown1.Value = GlobalWidth;
            numericUpDown2.Value = GlobalHeight;
            Opponents = inputOpponents;
            igrok = inputPlayer;
            UpdateAll();
        }

        private void UpdateAll()
        {
            pictureBox1.Image = (Image)new Bitmap(pictureBox1.Width, pictureBox1.Height);
            Graphics g = Graphics.FromImage(pictureBox1.Image);
            GenerateGrid(g);
            GenerateSop(g);
            GenerateGamer(g);
        }
        private void GenerateGrid(Graphics g)
        {
            g.Clear(Color.Gainsboro);
            Pen p = new Pen(Color.Blue);
            for (int i = 0; i < GlobalWidth; i++)
                g.DrawLine(p, new Point((pictureBox1.Width / GlobalWidth * (i + 1)), 0), new Point((pictureBox1.Width / GlobalWidth * (i + 1)), pictureBox1.Height));
            for (int j = 0; j < GlobalHeight; j++)
                g.DrawLine(p, new Point(0, (pictureBox1.Height / GlobalHeight * (j + 1))), new Point(pictureBox1.Width, (pictureBox1.Height / GlobalHeight * (j + 1))));
        }
        private void GenerateSop(Graphics g)
        {
            for (int i = 0; i < GlobalWidth; i++)
                for (int j = 0; j < GlobalHeight; j++)
                    if (Opponents[i, j] != null)
                    {
                        g.FillRectangle(Brushes.Red, (new Rectangle((int)pictureBox1.Width / GlobalWidth * i + 3, (int)pictureBox1.Height / GlobalHeight * j + 3, (int)pictureBox1.Width / GlobalWidth - 6, (int)pictureBox1.Height / GlobalHeight - 6)));
                        g.DrawString(Opponents[i, j].ToString(), new Font("Arial", 18), Brushes.Silver, new PointF((int)pictureBox1.Width / GlobalWidth * i, (int)pictureBox1.Height / GlobalHeight * j));
                    }
        }
        private void GenerateGamer(Graphics g)
        {
            g.FillRectangle(Brushes.Green, (new Rectangle((int)pictureBox1.Width / GlobalWidth * igrok.X + 3, (int)pictureBox1.Height / GlobalHeight * igrok.Y + 3, (int)pictureBox1.Width / GlobalWidth - 6, (int)pictureBox1.Height / GlobalHeight - 6)));
            g.DrawString(igrok.Force.ToString(), new Font("Arial", 18), Brushes.Silver, new PointF((int)pictureBox1.Width / GlobalWidth * igrok.X, (int)pictureBox1.Height / GlobalHeight * igrok.Y));
        }

        private void pictureBox1_SizeChanged(object sender, EventArgs e)
        {
            UpdateAll();
        }

        private void pictureBox1_MouseClick(object sender, MouseEventArgs e)
        {
            int X = pictureBox1.Width / GlobalWidth;
            int Y = pictureBox1.Height / GlobalHeight;
            for (int i = 1; i <= GlobalWidth; i++)
            {
                if (e.X <= (X * i))
                {
                    for (int j = 1; j <= GlobalHeight; j++)
                    {
                        if (e.Y <= (Y * j))
                        {
                            processingClick((i - 1), (j - 1), e);
                            UpdateAll();
                            break;
                        }
                    }
                    break;
                }
            }
        }

        private void processingClick(int inX, int inY, MouseEventArgs mouse)
        {
            if (mouse.Button == System.Windows.Forms.MouseButtons.Left)
                Opponents[inX, inY] = (int)levelSelect.Value;
            else if (mouse.Button == System.Windows.Forms.MouseButtons.Right)
                Opponents[inX, inY] = null;
            else if (mouse.Button == System.Windows.Forms.MouseButtons.Middle)
                igrok = new Player(inX, inY);
        }

        private void numericUpDown1_ValueChanged(object sender, EventArgs e)
        {
            GlobalWidth = (int)numericUpDown1.Value;
            NewGame();
        }

        private void numericUpDown2_ValueChanged(object sender, EventArgs e)
        {
            GlobalHeight = (int)numericUpDown2.Value;
            NewGame();
        }

        private void NewGame()
        {
            Opponents = new int?[GlobalWidth, GlobalHeight];
            igrok = new Player(0, 0);
            UpdateAll();
        }

        private void Save_Click(object sender, EventArgs e)
        {
            int OppnentsCount = 0;
            for (int i = 0; i < GlobalWidth; i++)
                for (int j = 0; j < GlobalHeight; j++)
                    if (Opponents[i, j] != null)
                        OppnentsCount++;

            SaveFileDialog sfd = new SaveFileDialog();

            sfd.Filter = "txt files (*.txt)|*.txt|All files (*.*)|*.*";
            sfd.RestoreDirectory = true;

            if (sfd.ShowDialog() == DialogResult.OK)
                using (StreamWriter sw = new StreamWriter(sfd.FileName))
                {
                    sw.WriteLine(GlobalWidth + " " + GlobalHeight);
                    sw.WriteLine(igrok.X + " " + igrok.Y + " " + igrok.Force + " " + OppnentsCount);
                    for (int i = 0; i < GlobalWidth; i++)
                        for (int j = 0; j < GlobalHeight; j++)
                            if (Opponents[i, j] != null)
                                sw.WriteLine(i + " " + j + " " + Opponents[i, j]);
                    sw.Close();
                }
        }

        private void CloseButton_Click(object sender, EventArgs e)
        {
            this.Close();
        }
    }
}
